/*
================================================================================
Ce programme affiche les valeurs de tous les capteurs sur l'écran TFT de la carte ESPLORA
 Il utilise la conversion itoa(char[],int,DEC) d'un entier en tableau de caractères.
 Le tableau de caractères char[] doit être défini avec une taille de + 1 par rapport à la taille
 renvoyée par String(int).length() sinon, on court au dépassement de mémoire et au plantage du 
 programme. Pour cela, le transtypage temporaire en String de int est nécessaire car la méthode 
 .length ne marche pas sur un entier.
 
 L'effacement est réalisé par la réécriture du même texte en noir.
 
 Laurent Coutelier
 Lycée Monge La chauvinière
 Nantes
 23/12/13
*/

// Importation des bibliothèques 
#include <Esplora.h> // Pour la carte ESPLORA
#include <SPI.h>  // Pour le bus SPI
#include <TFT.h>  // Pour l'écran TFT

//définition des variables communes
int xAxis, yAxis,  zAxis, xValue, yValue, button, Potlin, light, bp1, bp2, bp3, bp4, Temp, loudness;
int anc_xAxis, anc_yAxis,  anc_zAxis, anc_xValue, anc_yValue, anc_button, anc_Potlin, anc_light, anc_bp1, anc_bp2, anc_bp3, anc_bp4, anc_Temp, anc_loudness;

void setup()
{
  Serial.begin(9600);        // initialize serial communications with your computer
  EsploraTFT.begin();

  // Mise en place des affichages fixes
  EsploraTFT.background(0,0,0);  // Fond d'écran noir

  EsploraTFT.stroke(255,255,0);  // met la couleur en jaune
  EsploraTFT.text("AFFICHAGE DES CAPTEURS", 12,0);
  EsploraTFT.stroke(255,255,255);  // met la couleur en blanc
  EsploraTFT.text("JOYSTICK  X:     Y :    ", 0,10); 
  EsploraTFT.text("         BP:", 0,20);   
  EsploraTFT.text("LUMIERE:", 0,30);   
  EsploraTFT.text("SON:", 0,43); 
  EsploraTFT.text("CURSEUR:", 0,57);   
  EsploraTFT.text("TEMP:  'c", 0,71); 
  EsploraTFT.text("ACCELEROMETRE", 0,85);   
  EsploraTFT.text("X:      Y:      Z:", 0,94);   
  EsploraTFT.text("BOUTONS PAD", 0,107);   
  EsploraTFT.text("BP1:  BP2:  BP3:  BP4:", 0,118);  
  EsploraTFT.stroke(0,255,255);  // met la couleur en bleu 
} 

void loop()
{
  // lecture des capteurs
  xAxis = Esplora.readAccelerometer(X_AXIS);    // read the X axis
  yAxis = Esplora.readAccelerometer(Y_AXIS);    // read the Y axis
  zAxis = Esplora.readAccelerometer(Z_AXIS);    // read the Z axis
  xValue = Esplora.readJoystickX();        // read the joystick's X position
  yValue = Esplora.readJoystickY();        // read the joystick's Y position
  button = Esplora.readJoystickSwitch();   // read the joystick pushbutton
  Potlin = Esplora.readSlider();// lecture du potentiomètre linéaire
  light = Esplora.readLightSensor(); //lecture du capteur de lumière
  bp1 = Esplora.readButton(1);  // en bas
  bp2 = Esplora.readButton(2); //à gauche
  bp3 = Esplora.readButton(3);//en haut
  bp4 = Esplora.readButton(4); //à droite
  Temp = Esplora.readTemperature(DEGREES_C);
  loudness = Esplora.readMicrophone();

  // évaluation des changements de valeur et affichage en conséquence
   if(xAxis!=anc_xAxis){
   affiche(xAxis,4,  12, 94);
   anc_xAxis=xAxis;
   }
   if(yAxis!=anc_yAxis){
   affiche(yAxis,4,  60, 94);
   anc_yAxis=yAxis; 
   } 
   if(zAxis!=anc_zAxis){
   affiche(zAxis,4,  108,94);
   anc_zAxis=zAxis;  
   }
   if(xValue!=anc_xValue){
   affiche(xValue,4,  72, 10);
   anc_xValue=xValue; 
   }
   if(yValue!=anc_yValue){
   affiche(yValue,4,  120, 10);
   anc_yValue=yValue;   
   }
   if(button!=anc_button){
   affiche(button, 4,  72, 20);
   anc_button=button; 
   }
   if(Potlin!=anc_Potlin){
    affiche(Potlin, 4, 48, 57);
    anc_Potlin=Potlin;   
   }
   if(light!=anc_light){
   affiche(light,4,  48, 30);
   anc_light=light;   
   }
   if(bp1!=anc_bp1){
   affiche(bp1,1,  24, 118);
   anc_bp1=bp1;   
   }
   if(bp2!=anc_bp2){
   affiche(bp2,1,  60, 118);
   anc_bp2=bp2; 
   }
   if(bp3!=anc_bp3){
   affiche(bp3,1,  96, 118);//96, 107
   anc_bp3=bp3;  
   }
   if(bp4!=anc_bp4){
   affiche(bp4,1,  132, 118);
   anc_bp4=bp4;  
   }
   if(Temp!=anc_Temp){
   affiche(Temp, 2,  30, 71);
   anc_Temp=Temp;
   }
   if(loudness!=anc_loudness){
   affiche(loudness,3,  30, 43);
   anc_loudness=loudness;    
   }
   
  delay(300);
}


// Fonction d'affichage pour les valeurs modifiées
void affiche(int intvaleur, int n , int pos_x, int pos_y){
char T[n+1];  // création d'un tableau de caractère. Le +1 sinon dépassement et plantage.
itoa(intvaleur,T,DEC);  // conversion de l'entier en tableau de caractères

  // Efface la précédente valeur par un rectangle colorié de la largeur occupée par les n caractères
  EsploraTFT.stroke(0,0,0);  //traits noirs
  EsploraTFT.fill(0,0,0);  //coloriage noir
  EsploraTFT.rect(pos_x, pos_y,6*n, 8); // coordonnées et taille du rectangle
  EsploraTFT.noFill(); // fin de coloriage

  //affiche la nouvelle valeur
  EsploraTFT.stroke(0,255,255);  // met la couleur en blanc
  EsploraTFT.text(T, pos_x, pos_y);  // écrit les caractères de la valeur en blanc
}



