/*
================================================================================
 Ce programme affiche les valeurs de tous les capteurs sur l'écran TFT de la carte ESPLORA
 sous forme de barre-graphe.
 
 Laurent Coutelier
 Lycée Monge La chauvinière
 Nantes
 01/01/14
 */

// Importation des bibliothèques 
#include <Esplora.h> // Pour la carte ESPLORA
#include <SPI.h>  // Pour le bus SPI
#include <TFT.h>  // Pour l'écran TFT

//définition des variables communes
int xAxis, yAxis,  zAxis, xValue, yValue, button, Potlin, light, bp1, bp2, bp3, bp4, Temp, loudness;
int anc_xAxis, anc_yAxis,  anc_zAxis, anc_xValue, anc_yValue, anc_button, anc_Potlin, anc_light, anc_bp1, anc_bp2, anc_bp3, anc_bp4, anc_Temp, anc_loudness;

void setup(){
  //Serial.begin(9600);        // initialize serial communications with your computer
  EsploraTFT.begin();

  // Mise en place des affichages fixes
  EsploraTFT.background(0,0,0);  // Fond d'écran noir
  EsploraTFT.stroke(255,255,255);  // met la couleur en blanc
  EsploraTFT.text("JOY.X", 0,0); 
  EsploraTFT.text("JOY.Y", 0,8);   
  EsploraTFT.text("JOYBP", 0,16);   
  EsploraTFT.text("LUM.", 0,24);   
  EsploraTFT.text("SON", 0,32); 
  EsploraTFT.text("CURS.", 0,40);   
  EsploraTFT.text("TEMP.", 0,48); 
  EsploraTFT.text("ACC X", 0,56); 
  EsploraTFT.text("ACC X", 0,64);  
  EsploraTFT.text("ACC Z", 0,72);   
  EsploraTFT.text("sw1", 0,80);  
  EsploraTFT.text("sw2", 0,88); 
  EsploraTFT.text("sw3", 0,96); 
  EsploraTFT.text("sw4", 0,104); 
} 

void loop()
{
  // lecture des capteurs
  xAxis = Esplora.readAccelerometer(X_AXIS);    // read the X axis
  yAxis = Esplora.readAccelerometer(Y_AXIS);    // read the Y axis
  zAxis = Esplora.readAccelerometer(Z_AXIS);    // read the Z axis
  xValue = Esplora.readJoystickX();        // read the joystick's X position
  yValue = Esplora.readJoystickY();        // read the joystick's Y position
  button = Esplora.readJoystickSwitch();   // read the joystick pushbutton
  Potlin = Esplora.readSlider();      // lecture du potentiomètre linéaire
  light = Esplora.readLightSensor();  // lecture du capteur de lumière
  bp1 = Esplora.readButton(1); // en bas
  bp2 = Esplora.readButton(2); // à gauche
  bp3 = Esplora.readButton(3); // en haut
  bp4 = Esplora.readButton(4); // à droite
  Temp = Esplora.readTemperature(DEGREES_C);
  loudness = Esplora.readMicrophone();

  // évaluation des changements de valeur et affichage en conséquence
//Joystick X
    if(xValue!=anc_xValue){
    int jx=map(xValue,-512, 511, 30, 159);
    if(jx<94){
      affiche(jx, 1, 94-jx); 
    }
    else{   
      affiche(94, 1, jx-94);
    }
    anc_xValue=xValue; 
  }

//Joystick Y
  if(yValue!=anc_yValue){
    int jy=map(yValue,-512, 511, 30, 159);
    if(jy<94){
      affiche(jy, 9, 94-jy); 
    }
    else{   
      affiche(94.5, 9, jy-94);
    }
    anc_yValue=yValue;   
  }
  
//Joystick Bouton
  if(button!=anc_button){
    affiche(30,17, map(button,0,1023, 1, 159-29));
    //Serial.println(map(button,0,1023, 0, 159-29));
    anc_button=button; 
  }
  
//Lumière
  if(light!=anc_light){
    affiche(30,25, map(light,0,1023, 1, 159-29));
    anc_light=light;   
  }
  
// Niveau de son  
  if(loudness!=anc_loudness){
    affiche(30,33, map(loudness,0,1023, 1, 159-29));
    anc_loudness=loudness;    
  }
  
// Curseur linéaire
  if(Potlin!=anc_Potlin){
    affiche(30,41, map(Potlin,0,1023, 1, 159-29));
    anc_Potlin=Potlin;   
  }
  
// Température
  if(Temp!=anc_Temp){
    affiche(30,49,  map(Temp,0, 50, 0, 159-29));
    anc_Temp=Temp;
  }
  
// Accélération X
  if(xAxis!=anc_xAxis){
    int x=map(xAxis,-512,511, 30, 159);
    if(x<94.5){
      affiche(x, 56, 94.5-x); 
    }
    else{   
      affiche(94.5, 56, x-94.5);
    }
    anc_xAxis=xAxis;
  }

// Accélération Y
  if(yAxis!=anc_yAxis){
    int y=map(yAxis,-512,511, 30, 159);
    if(y<94.5){
      affiche(y, 64, 94.5-y); 
    }
    else{   
      affiche(94.5, 64, y-94.5);
    }
    anc_yAxis=yAxis;
  }

// Accélération Z
  if(zAxis!=anc_zAxis){
    int z=map(zAxis,-512,511, 30, 159);
    if(z<94.5){

      affiche(z, 72, 94.5-z); 
    }
    else{   
      affiche(94.5, 72, z-94.5);
    }
    anc_zAxis=zAxis;  
  }

//Pad BP1
  if(bp1!=anc_bp1){
    carre(bp1,81);
    anc_bp1=bp1;   
  }

//Pad BP2
  if(bp2!=anc_bp2){
    carre(bp2,89);
    anc_bp2=bp2; 
  }

//Pad BP3
  if(bp3!=anc_bp3){
    carre(bp3,97);
    anc_bp3=bp3;  
  }
//Pad BP4
  if(bp4!=anc_bp4){
    carre(bp4,105);
    anc_bp4=bp4;  
  }
  delay(50); //délai de stabilisation de l'image (rémanence rétinienne)
}




// Fonction d'affichage pour les valeurs modifiées
void affiche(int pos_x, int pos_y, int largeur ){

  // Efface la précédente valeur par un rectangle colorié de la largeur occupée par les n caractères
  EsploraTFT.stroke(0,0,0);  //traits noirs
  EsploraTFT.fill(0,0,0);  //coloriage noir
  EsploraTFT.rect(30, pos_y,159-29,6); // coordonnées et taille du rectangle
  //EsploraTFT.noFill(); // fin de coloriage

  //affiche la nouvelle valeur
  EsploraTFT.stroke(0,255,255);  // met la couleur en turquoise
  EsploraTFT.fill(0,255,255);  //coloriage turquoise
  EsploraTFT.rect(pos_x, pos_y,largeur, 6); // coordonnées et taille du rectangle
  //EsploraTFT.noFill(); // fin de coloriage
}




// Fonction d'affichage carré plein / vide pour les 4 boutons 
void carre(int bp, int pos_y){
  if(bp==1){
    // rectangle plein
    EsploraTFT.stroke(0,255,255);  // met la couleur en turquoise
    EsploraTFT.fill(0,255,255);  //coloriage turquoise
    EsploraTFT.rect(30, pos_y, 6, 6); // coordonnées et taille du rectangle
  }
  else{
    // rectangle vide
    EsploraTFT.stroke(0,255,255);  //traits turquoise
    EsploraTFT.fill(0,0,0);  //coloriage noir
    EsploraTFT.rect(30, pos_y, 6, 6); // coordonnées et taille du rectangle 
  }
}

